
# Server Management Tools

There are several management tools for the server, they are all accessible by `lrs-<tool_name>`.  

All managements tools include:
```sh
lrs-resetconf   # To reset default configuration
lrs-cluster     # Cluster management
lrs-user        # Manage user accounts
lrs-index       # To build and query feature of the database, for fuzzy search
lrs-utils       # Miscellaneous utilities (e.g. download pdf.js and edit configuration file)
```

## ...
